@@ -156,8 +156,7 @@ class Document:
             self._client.session.get(u'{}/documents/{}/state'.format(
                 self._client.base_url, self.document_id)))
 
-        return DocumentState(json['currentState'], json['description'],
-                             json['aditionalInfo'], json.get('signatures'))
+        return DocumentState(json)
 
     def get_history(self):
         '''
@@ -180,9 +179,6 @@ class Document:
         Retorna o recibo do documento. Por exemplo::
 
             {
-                "raw_signatures": [
-                    "string"
-                ],
                 "doc_type": "string",
                 "status": "string",
                 "dlt_id": "string",
@@ -481,6 +477,9 @@ class DocumentSignature:
         #: Identificador do assinante.
         self.signer_id = json.get('signerId')
 
+        #: Data e hora da assinatura, em string no formato ISO 8601.
+        self.signature_date = json.get('signatureDate')
+
         #: Tag da assinatura.
         self.tag = json.get('tag')
 
@@ -530,28 +529,43 @@ class DocumentSignatureState:
 class DocumentState:
     '''Representação do estado atual do processamento de um documento.'''
 
-    def __init__(self, current_state, description, additional_info,
-                 signatures):
+    def __init__(self, json):
         #: Código de estado atual do documento. Ver
         #: :class:`DocumentStateCode <DocumentStateCode>`.
-        self.current_state = current_state
+        self.current_state = json['currentState']
 
         #: Descrição textual do estado atual do documento.
-        self.description = description
+        self.description = json['description']
 
         #: Informações adicionais sobre o estado atual do documento.
-        self.additional_info = additional_info
+        self.additional_info = json['aditionalInfo']
+
+        signatures = json.get('signatures')
 
         #: Assinaturas do documento. Ver
-        #: :class:`DocumentSignature <DocumentSignature>`.
+        #: :class:`DocumentSignature <DocumentSignature>`. Possivelmente nulo.
         self.signatures = [DocumentSignature(s) for s in signatures] \
             if signatures else None
 
+        #: Motivo de revogação do documento. Ver
+        #: :class:`DocumentRevocationData <DocumentRevocationData>`.
+        #: Possivelmente nulo.
+        self.revocation = None
+
+        revocation = json.get('revocation', {})
+        if 'reason' in revocation or 'notes' in revocation:
+            self.revocation = DocumentRevocationData(
+                revocation.get('reason'), revocation.get('notes', ''))
+
+        #: Data e a hora da última vez que algum dado do documento sofreu
+        #: alteração, no formato ISO 8601. Possivelmente nulo.
+        self.last_update = json.get('lastUpdate')
+
     def __repr__(self):
         return '{}(current_state={}, description={}, additional_info={}, ' \
-            'signatures={})'.format(
+            'signatures={}, last_update={})'.format(
             self.__class__.__name__, str(self.current_state), self.description,
-            self.additional_info, str(self.signatures))
+            self.additional_info, str(self.signatures), self.last_update)
 
 
 class DocumentStateChange:
@@ -708,7 +722,7 @@ class DocumentRevocationData:
         '''
         Inicializa um objeto contendo dados sobre a revogação de um documento.
 
-        :param reason: Justificativa da revogação.
+        :param reason: String contendo a justificativa da revogação.
         :type reason: DocumentRevocationReason
 
         :param notes: Observações adicionais sobre a revogação.
